# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/k8score/v1/k8score.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/k8score/v1/k8score.proto',
  package='github.com.metaprov.modelaapi.services.k8score.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/k8score/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/k8score/v1/k8score.proto\x12\x31github.com.metaprov.modelaapi.services.k8score.v1\x1a\x1cgoogle/api/annotations.proto\x1a\"k8s.io/api/core/v1/generated.proto\"\xc3\x01\n\x10GetSecretRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12_\n\x06labels\x18\x03 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x11GetSecretResponse\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.services.k8score.v1.SecretInfo\"\xb9\x01\n\x12ListSecretsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x61\n\x06labels\x18\x03 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x12ListSecretResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.services.k8score.v1.SecretInfo\"\xcb\x01\n\x14GetDeploymentRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x63\n\x06labels\x18\x03 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x15GetDeploymentResponse\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo\"\xc1\x01\n\x16ListDeploymentsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x65\n\x06labels\x18\x03 \x03(\x0b\x32U.github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x17ListDeploymentsResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo\"\xc5\x01\n\x11GetServiceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12`\n\x06labels\x18\x03 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x12GetServiceResponse\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo\"\xbb\x01\n\x13ListServicesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x03 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x14ListServicesResponse\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo\"\xbd\x01\n\rGetPodRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\\\n\x06labels\x18\x03 \x03(\x0b\x32L.github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Z\n\x0eGetPodResponse\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.services.k8score.v1.PodInfo\"\xb3\x01\n\x0fListPodsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12^\n\x06labels\x18\x03 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x10ListPodsResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.github.com.metaprov.modelaapi.services.k8score.v1.PodInfo\"\xbd\x01\n\rGetJobRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\\\n\x06labels\x18\x03 \x03(\x0b\x32L.github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Z\n\x0eGetJobResponse\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.services.k8score.v1.PodInfo\"\xb3\x01\n\x0fListJobsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12^\n\x06labels\x18\x03 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x10ListJobsResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.github.com.metaprov.modelaapi.services.k8score.v1.JobInfo\"\xc5\x01\n\x11ListEventsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12`\n\x06labels\x18\x03 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"B\n\x12ListEventsResponse\x12,\n\x05items\x18\x01 \x01(\x0b\x32\x1d.k8s.io.api.core.v1.EventList\"-\n\nSecretInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\".\n\x0bServiceInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"1\n\x0e\x44\x65ploymentInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"*\n\x07PodInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"*\n\x07JobInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t2\xd0\x10\n\x0e\x43oreK8sService\x12\xbd\x01\n\x0eListK8sSecrets\x12\x45.github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest\x1a\x45.github.com.metaprov.modelaapi.services.k8score.v1.ListSecretResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1alpha1/secrets\x12\xbf\x01\n\x0cGetK8sSecret\x12\x43.github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest\x1a\x44.github.com.metaprov.modelaapi.services.k8score.v1.GetSecretResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1alpha1/secrets/{name}\x12\xc2\x01\n\x0fListK8sServices\x12\x46.github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest\x1aG.github.com.metaprov.modelaapi.services.k8score.v1.ListServicesResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1alpha1/services\x12\xc3\x01\n\rGetK8sService\x12\x44.github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest\x1a\x45.github.com.metaprov.modelaapi.services.k8score.v1.GetServiceResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/api/v1alpha1/services/{name}\x12\xce\x01\n\x12ListK8sDeployments\x12I.github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest\x1aJ.github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1alpha1/deployments\x12\xcf\x01\n\x10GetK8sDeployment\x12G.github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest\x1aH.github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1alpha1/deployments/{name}\x12\xb2\x01\n\x0bListK8sPods\x12\x42.github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest\x1a\x43.github.com.metaprov.modelaapi.services.k8score.v1.ListPodsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/api/v1alpha1/pods\x12\xb3\x01\n\tGetK8sPod\x12@.github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest\x1a\x41.github.com.metaprov.modelaapi.services.k8score.v1.GetPodResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1alpha1/pods/{name}\x12\xb2\x01\n\x0bListK8sJobs\x12\x42.github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest\x1a\x43.github.com.metaprov.modelaapi.services.k8score.v1.ListJobsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/api/v1alpha1/jobs\x12\xb3\x01\n\tGetK8sJob\x12@.github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest\x1a\x41.github.com.metaprov.modelaapi.services.k8score.v1.GetJobResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1alpha1/jobs/{name}\x12\xb7\x01\n\nListEvents\x12\x44.github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest\x1a\x45.github.com.metaprov.modelaapi.services.k8score.v1.ListEventsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1alpha1/eventsB3Z1github.com/metaprov/modelaapi/services/k8score/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2.DESCRIPTOR,])




_GETSECRETREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_GETSECRETREQUEST = _descriptor.Descriptor(
  name='GetSecretRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETSECRETREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=380,
)


_GETSECRETRESPONSE = _descriptor.Descriptor(
  name='GetSecretResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetSecretResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetSecretResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=478,
)


_LISTSECRETSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_LISTSECRETSREQUEST = _descriptor.Descriptor(
  name='ListSecretsRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSECRETSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=666,
)


_LISTSECRETRESPONSE = _descriptor.Descriptor(
  name='ListSecretResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListSecretResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListSecretResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=668,
  serialized_end=766,
)


_GETDEPLOYMENTREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_GETDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='GetDeploymentRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETDEPLOYMENTREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=972,
)


_GETDEPLOYMENTRESPONSE = _descriptor.Descriptor(
  name='GetDeploymentResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=974,
  serialized_end=1078,
)


_LISTDEPLOYMENTSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_LISTDEPLOYMENTSREQUEST = _descriptor.Descriptor(
  name='ListDeploymentsRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTDEPLOYMENTSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1274,
)


_LISTDEPLOYMENTSRESPONSE = _descriptor.Descriptor(
  name='ListDeploymentsResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1276,
  serialized_end=1383,
)


_GETSERVICEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_GETSERVICEREQUEST = _descriptor.Descriptor(
  name='GetServiceRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETSERVICEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1386,
  serialized_end=1583,
)


_GETSERVICERESPONSE = _descriptor.Descriptor(
  name='GetServiceResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetServiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetServiceResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1585,
  serialized_end=1683,
)


_LISTSERVICESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_LISTSERVICESREQUEST = _descriptor.Descriptor(
  name='ListServicesRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSERVICESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1686,
  serialized_end=1873,
)


_LISTSERVICESRESPONSE = _descriptor.Descriptor(
  name='ListServicesResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListServicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListServicesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1875,
  serialized_end=1976,
)


_GETPODREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_GETPODREQUEST = _descriptor.Descriptor(
  name='GetPodRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETPODREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1979,
  serialized_end=2168,
)


_GETPODRESPONSE = _descriptor.Descriptor(
  name='GetPodResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetPodResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetPodResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2170,
  serialized_end=2260,
)


_LISTPODSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_LISTPODSREQUEST = _descriptor.Descriptor(
  name='ListPodsRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPODSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2263,
  serialized_end=2442,
)


_LISTPODSRESPONSE = _descriptor.Descriptor(
  name='ListPodsResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListPodsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListPodsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2444,
  serialized_end=2537,
)


_GETJOBREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_GETJOBREQUEST = _descriptor.Descriptor(
  name='GetJobRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETJOBREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2540,
  serialized_end=2729,
)


_GETJOBRESPONSE = _descriptor.Descriptor(
  name='GetJobResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.k8score.v1.GetJobResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2731,
  serialized_end=2821,
)


_LISTJOBSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_LISTJOBSREQUEST = _descriptor.Descriptor(
  name='ListJobsRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTJOBSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2824,
  serialized_end=3003,
)


_LISTJOBSRESPONSE = _descriptor.Descriptor(
  name='ListJobsResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListJobsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3005,
  serialized_end=3098,
)


_LISTEVENTSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)

_LISTEVENTSREQUEST = _descriptor.Descriptor(
  name='ListEventsRequest',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTEVENTSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3101,
  serialized_end=3298,
)


_LISTEVENTSRESPONSE = _descriptor.Descriptor(
  name='ListEventsResponse',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ListEventsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3300,
  serialized_end=3366,
)


_SECRETINFO = _descriptor.Descriptor(
  name='SecretInfo',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.SecretInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.SecretInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.SecretInfo.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3368,
  serialized_end=3413,
)


_SERVICEINFO = _descriptor.Descriptor(
  name='ServiceInfo',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3415,
  serialized_end=3461,
)


_DEPLOYMENTINFO = _descriptor.Descriptor(
  name='DeploymentInfo',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3463,
  serialized_end=3512,
)


_PODINFO = _descriptor.Descriptor(
  name='PodInfo',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.PodInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.PodInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.PodInfo.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3514,
  serialized_end=3556,
)


_JOBINFO = _descriptor.Descriptor(
  name='JobInfo',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.JobInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.k8score.v1.JobInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.k8score.v1.JobInfo.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3558,
  serialized_end=3600,
)

_GETSECRETREQUEST_LABELSENTRY.containing_type = _GETSECRETREQUEST
_GETSECRETREQUEST.fields_by_name['labels'].message_type = _GETSECRETREQUEST_LABELSENTRY
_GETSECRETRESPONSE.fields_by_name['item'].message_type = _SECRETINFO
_LISTSECRETSREQUEST_LABELSENTRY.containing_type = _LISTSECRETSREQUEST
_LISTSECRETSREQUEST.fields_by_name['labels'].message_type = _LISTSECRETSREQUEST_LABELSENTRY
_LISTSECRETRESPONSE.fields_by_name['items'].message_type = _SECRETINFO
_GETDEPLOYMENTREQUEST_LABELSENTRY.containing_type = _GETDEPLOYMENTREQUEST
_GETDEPLOYMENTREQUEST.fields_by_name['labels'].message_type = _GETDEPLOYMENTREQUEST_LABELSENTRY
_GETDEPLOYMENTRESPONSE.fields_by_name['item'].message_type = _DEPLOYMENTINFO
_LISTDEPLOYMENTSREQUEST_LABELSENTRY.containing_type = _LISTDEPLOYMENTSREQUEST
_LISTDEPLOYMENTSREQUEST.fields_by_name['labels'].message_type = _LISTDEPLOYMENTSREQUEST_LABELSENTRY
_LISTDEPLOYMENTSRESPONSE.fields_by_name['items'].message_type = _DEPLOYMENTINFO
_GETSERVICEREQUEST_LABELSENTRY.containing_type = _GETSERVICEREQUEST
_GETSERVICEREQUEST.fields_by_name['labels'].message_type = _GETSERVICEREQUEST_LABELSENTRY
_GETSERVICERESPONSE.fields_by_name['item'].message_type = _SERVICEINFO
_LISTSERVICESREQUEST_LABELSENTRY.containing_type = _LISTSERVICESREQUEST
_LISTSERVICESREQUEST.fields_by_name['labels'].message_type = _LISTSERVICESREQUEST_LABELSENTRY
_LISTSERVICESRESPONSE.fields_by_name['items'].message_type = _SERVICEINFO
_GETPODREQUEST_LABELSENTRY.containing_type = _GETPODREQUEST
_GETPODREQUEST.fields_by_name['labels'].message_type = _GETPODREQUEST_LABELSENTRY
_GETPODRESPONSE.fields_by_name['item'].message_type = _PODINFO
_LISTPODSREQUEST_LABELSENTRY.containing_type = _LISTPODSREQUEST
_LISTPODSREQUEST.fields_by_name['labels'].message_type = _LISTPODSREQUEST_LABELSENTRY
_LISTPODSRESPONSE.fields_by_name['items'].message_type = _PODINFO
_GETJOBREQUEST_LABELSENTRY.containing_type = _GETJOBREQUEST
_GETJOBREQUEST.fields_by_name['labels'].message_type = _GETJOBREQUEST_LABELSENTRY
_GETJOBRESPONSE.fields_by_name['item'].message_type = _PODINFO
_LISTJOBSREQUEST_LABELSENTRY.containing_type = _LISTJOBSREQUEST
_LISTJOBSREQUEST.fields_by_name['labels'].message_type = _LISTJOBSREQUEST_LABELSENTRY
_LISTJOBSRESPONSE.fields_by_name['items'].message_type = _JOBINFO
_LISTEVENTSREQUEST_LABELSENTRY.containing_type = _LISTEVENTSREQUEST
_LISTEVENTSREQUEST.fields_by_name['labels'].message_type = _LISTEVENTSREQUEST_LABELSENTRY
_LISTEVENTSRESPONSE.fields_by_name['items'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._EVENTLIST
DESCRIPTOR.message_types_by_name['GetSecretRequest'] = _GETSECRETREQUEST
DESCRIPTOR.message_types_by_name['GetSecretResponse'] = _GETSECRETRESPONSE
DESCRIPTOR.message_types_by_name['ListSecretsRequest'] = _LISTSECRETSREQUEST
DESCRIPTOR.message_types_by_name['ListSecretResponse'] = _LISTSECRETRESPONSE
DESCRIPTOR.message_types_by_name['GetDeploymentRequest'] = _GETDEPLOYMENTREQUEST
DESCRIPTOR.message_types_by_name['GetDeploymentResponse'] = _GETDEPLOYMENTRESPONSE
DESCRIPTOR.message_types_by_name['ListDeploymentsRequest'] = _LISTDEPLOYMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListDeploymentsResponse'] = _LISTDEPLOYMENTSRESPONSE
DESCRIPTOR.message_types_by_name['GetServiceRequest'] = _GETSERVICEREQUEST
DESCRIPTOR.message_types_by_name['GetServiceResponse'] = _GETSERVICERESPONSE
DESCRIPTOR.message_types_by_name['ListServicesRequest'] = _LISTSERVICESREQUEST
DESCRIPTOR.message_types_by_name['ListServicesResponse'] = _LISTSERVICESRESPONSE
DESCRIPTOR.message_types_by_name['GetPodRequest'] = _GETPODREQUEST
DESCRIPTOR.message_types_by_name['GetPodResponse'] = _GETPODRESPONSE
DESCRIPTOR.message_types_by_name['ListPodsRequest'] = _LISTPODSREQUEST
DESCRIPTOR.message_types_by_name['ListPodsResponse'] = _LISTPODSRESPONSE
DESCRIPTOR.message_types_by_name['GetJobRequest'] = _GETJOBREQUEST
DESCRIPTOR.message_types_by_name['GetJobResponse'] = _GETJOBRESPONSE
DESCRIPTOR.message_types_by_name['ListJobsRequest'] = _LISTJOBSREQUEST
DESCRIPTOR.message_types_by_name['ListJobsResponse'] = _LISTJOBSRESPONSE
DESCRIPTOR.message_types_by_name['ListEventsRequest'] = _LISTEVENTSREQUEST
DESCRIPTOR.message_types_by_name['ListEventsResponse'] = _LISTEVENTSRESPONSE
DESCRIPTOR.message_types_by_name['SecretInfo'] = _SECRETINFO
DESCRIPTOR.message_types_by_name['ServiceInfo'] = _SERVICEINFO
DESCRIPTOR.message_types_by_name['DeploymentInfo'] = _DEPLOYMENTINFO
DESCRIPTOR.message_types_by_name['PodInfo'] = _PODINFO
DESCRIPTOR.message_types_by_name['JobInfo'] = _JOBINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSecretRequest = _reflection.GeneratedProtocolMessageType('GetSecretRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETSECRETREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETSECRETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest)
  })
_sym_db.RegisterMessage(GetSecretRequest)
_sym_db.RegisterMessage(GetSecretRequest.LabelsEntry)

GetSecretResponse = _reflection.GeneratedProtocolMessageType('GetSecretResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSECRETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetSecretResponse)
  })
_sym_db.RegisterMessage(GetSecretResponse)

ListSecretsRequest = _reflection.GeneratedProtocolMessageType('ListSecretsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSECRETSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSECRETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest)
  })
_sym_db.RegisterMessage(ListSecretsRequest)
_sym_db.RegisterMessage(ListSecretsRequest.LabelsEntry)

ListSecretResponse = _reflection.GeneratedProtocolMessageType('ListSecretResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSECRETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListSecretResponse)
  })
_sym_db.RegisterMessage(ListSecretResponse)

GetDeploymentRequest = _reflection.GeneratedProtocolMessageType('GetDeploymentRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETDEPLOYMENTREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETDEPLOYMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest)
  })
_sym_db.RegisterMessage(GetDeploymentRequest)
_sym_db.RegisterMessage(GetDeploymentRequest.LabelsEntry)

GetDeploymentResponse = _reflection.GeneratedProtocolMessageType('GetDeploymentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDEPLOYMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentResponse)
  })
_sym_db.RegisterMessage(GetDeploymentResponse)

ListDeploymentsRequest = _reflection.GeneratedProtocolMessageType('ListDeploymentsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDEPLOYMENTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDEPLOYMENTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest)
  })
_sym_db.RegisterMessage(ListDeploymentsRequest)
_sym_db.RegisterMessage(ListDeploymentsRequest.LabelsEntry)

ListDeploymentsResponse = _reflection.GeneratedProtocolMessageType('ListDeploymentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEPLOYMENTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsResponse)
  })
_sym_db.RegisterMessage(ListDeploymentsResponse)

GetServiceRequest = _reflection.GeneratedProtocolMessageType('GetServiceRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETSERVICEREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETSERVICEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest)
  })
_sym_db.RegisterMessage(GetServiceRequest)
_sym_db.RegisterMessage(GetServiceRequest.LabelsEntry)

GetServiceResponse = _reflection.GeneratedProtocolMessageType('GetServiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetServiceResponse)
  })
_sym_db.RegisterMessage(GetServiceResponse)

ListServicesRequest = _reflection.GeneratedProtocolMessageType('ListServicesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSERVICESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSERVICESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest)
  })
_sym_db.RegisterMessage(ListServicesRequest)
_sym_db.RegisterMessage(ListServicesRequest.LabelsEntry)

ListServicesResponse = _reflection.GeneratedProtocolMessageType('ListServicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListServicesResponse)
  })
_sym_db.RegisterMessage(ListServicesResponse)

GetPodRequest = _reflection.GeneratedProtocolMessageType('GetPodRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETPODREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETPODREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest)
  })
_sym_db.RegisterMessage(GetPodRequest)
_sym_db.RegisterMessage(GetPodRequest.LabelsEntry)

GetPodResponse = _reflection.GeneratedProtocolMessageType('GetPodResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPODRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetPodResponse)
  })
_sym_db.RegisterMessage(GetPodResponse)

ListPodsRequest = _reflection.GeneratedProtocolMessageType('ListPodsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPODSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPODSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest)
  })
_sym_db.RegisterMessage(ListPodsRequest)
_sym_db.RegisterMessage(ListPodsRequest.LabelsEntry)

ListPodsResponse = _reflection.GeneratedProtocolMessageType('ListPodsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPODSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListPodsResponse)
  })
_sym_db.RegisterMessage(ListPodsResponse)

GetJobRequest = _reflection.GeneratedProtocolMessageType('GetJobRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETJOBREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETJOBREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest)
  })
_sym_db.RegisterMessage(GetJobRequest)
_sym_db.RegisterMessage(GetJobRequest.LabelsEntry)

GetJobResponse = _reflection.GeneratedProtocolMessageType('GetJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetJobResponse)
  })
_sym_db.RegisterMessage(GetJobResponse)

ListJobsRequest = _reflection.GeneratedProtocolMessageType('ListJobsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTJOBSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTJOBSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest)
  })
_sym_db.RegisterMessage(ListJobsRequest)
_sym_db.RegisterMessage(ListJobsRequest.LabelsEntry)

ListJobsResponse = _reflection.GeneratedProtocolMessageType('ListJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListJobsResponse)
  })
_sym_db.RegisterMessage(ListJobsResponse)

ListEventsRequest = _reflection.GeneratedProtocolMessageType('ListEventsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTEVENTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTEVENTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest)
  })
_sym_db.RegisterMessage(ListEventsRequest)
_sym_db.RegisterMessage(ListEventsRequest.LabelsEntry)

ListEventsResponse = _reflection.GeneratedProtocolMessageType('ListEventsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListEventsResponse)
  })
_sym_db.RegisterMessage(ListEventsResponse)

SecretInfo = _reflection.GeneratedProtocolMessageType('SecretInfo', (_message.Message,), {
  'DESCRIPTOR' : _SECRETINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.SecretInfo)
  })
_sym_db.RegisterMessage(SecretInfo)

ServiceInfo = _reflection.GeneratedProtocolMessageType('ServiceInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo)
  })
_sym_db.RegisterMessage(ServiceInfo)

DeploymentInfo = _reflection.GeneratedProtocolMessageType('DeploymentInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo)
  })
_sym_db.RegisterMessage(DeploymentInfo)

PodInfo = _reflection.GeneratedProtocolMessageType('PodInfo', (_message.Message,), {
  'DESCRIPTOR' : _PODINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.PodInfo)
  })
_sym_db.RegisterMessage(PodInfo)

JobInfo = _reflection.GeneratedProtocolMessageType('JobInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.JobInfo)
  })
_sym_db.RegisterMessage(JobInfo)


DESCRIPTOR._options = None
_GETSECRETREQUEST_LABELSENTRY._options = None
_LISTSECRETSREQUEST_LABELSENTRY._options = None
_GETDEPLOYMENTREQUEST_LABELSENTRY._options = None
_LISTDEPLOYMENTSREQUEST_LABELSENTRY._options = None
_GETSERVICEREQUEST_LABELSENTRY._options = None
_LISTSERVICESREQUEST_LABELSENTRY._options = None
_GETPODREQUEST_LABELSENTRY._options = None
_LISTPODSREQUEST_LABELSENTRY._options = None
_GETJOBREQUEST_LABELSENTRY._options = None
_LISTJOBSREQUEST_LABELSENTRY._options = None
_LISTEVENTSREQUEST_LABELSENTRY._options = None

_COREK8SSERVICE = _descriptor.ServiceDescriptor(
  name='CoreK8sService',
  full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3603,
  serialized_end=5731,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListK8sSecrets',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.ListK8sSecrets',
    index=0,
    containing_service=None,
    input_type=_LISTSECRETSREQUEST,
    output_type=_LISTSECRETRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/api/v1alpha1/secrets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetK8sSecret',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.GetK8sSecret',
    index=1,
    containing_service=None,
    input_type=_GETSECRETREQUEST,
    output_type=_GETSECRETRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/api/v1alpha1/secrets/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListK8sServices',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.ListK8sServices',
    index=2,
    containing_service=None,
    input_type=_LISTSERVICESREQUEST,
    output_type=_LISTSERVICESRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/api/v1alpha1/services',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetK8sService',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.GetK8sService',
    index=3,
    containing_service=None,
    input_type=_GETSERVICEREQUEST,
    output_type=_GETSERVICERESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/api/v1alpha1/services/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListK8sDeployments',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.ListK8sDeployments',
    index=4,
    containing_service=None,
    input_type=_LISTDEPLOYMENTSREQUEST,
    output_type=_LISTDEPLOYMENTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/api/v1alpha1/deployments',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetK8sDeployment',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.GetK8sDeployment',
    index=5,
    containing_service=None,
    input_type=_GETDEPLOYMENTREQUEST,
    output_type=_GETDEPLOYMENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /api/v1alpha1/deployments/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListK8sPods',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.ListK8sPods',
    index=6,
    containing_service=None,
    input_type=_LISTPODSREQUEST,
    output_type=_LISTPODSRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\022\022/api/v1alpha1/pods',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetK8sPod',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.GetK8sPod',
    index=7,
    containing_service=None,
    input_type=_GETPODREQUEST,
    output_type=_GETPODRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/api/v1alpha1/pods/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListK8sJobs',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.ListK8sJobs',
    index=8,
    containing_service=None,
    input_type=_LISTJOBSREQUEST,
    output_type=_LISTJOBSRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\022\022/api/v1alpha1/jobs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetK8sJob',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.GetK8sJob',
    index=9,
    containing_service=None,
    input_type=_GETJOBREQUEST,
    output_type=_GETJOBRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/api/v1alpha1/jobs/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEvents',
    full_name='github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService.ListEvents',
    index=10,
    containing_service=None,
    input_type=_LISTEVENTSREQUEST,
    output_type=_LISTEVENTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/api/v1alpha1/events',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COREK8SSERVICE)

DESCRIPTOR.services_by_name['CoreK8sService'] = _COREK8SSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featurepipelinerun/v1/featurepipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/featurepipelinerun/v1/featurepipelinerun.proto',
  package='github.com.metaprov.modelaapi.services.featurepipelinerun.v1',
  syntax='proto3',
  serialized_options=b'Z<github.com/metaprov/modelaapi/services/featurepipelinerun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nUgithub.com/metaprov/modelaapi/services/featurepipelinerun/v1/featurepipelinerun.proto\x12<github.com.metaprov.modelaapi.services.featurepipelinerun.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xda\x01\n\x1dListFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12w\n\x06labels\x18\x02 \x03(\x0b\x32g.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"}\n\x1eListFeaturePipelineRunResponse\x12[\n\x05items\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRunList\"y\n\x1f\x43reateFeaturePipelineRunRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\"\n CreateFeaturePipelineRunResponse\"y\n\x1fUpdateFeaturePipelineRunRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\"\n UpdateFeaturePipelineRunResponse\"?\n\x1cGetFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x01\n\x1dGetFeaturePipelineRunResponse\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"B\n\x1f\x44\x65leteFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\"\n DeleteFeaturePipelineRunResponse2\x81\n\n\x19\x46\x65\x61turePipelineRunService\x12\xf5\x01\n\x17ListFeaturePipelineRuns\x12[.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest\x1a\\.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/featurepipelineruns\x12\xfd\x01\n\x18\x43reateFeaturePipelineRun\x12].github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/featurepipelineruns:\x01*\x12\xf8\x01\n\x15GetFeaturePipelineRun\x12Z.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunRequest\x1a[.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/featurepipelineruns/{name}\x12\x92\x02\n\x18UpdateFeaturePipelineRun\x12].github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunResponse\"7\x82\xd3\xe4\x93\x02\x31\x1a,/v1/featurepipelines/{feature.metadata.name}:\x01*\x12\xdb\x01\n\x18\x44\x65leteFeaturePipelineRun\x12].github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunResponse\"\x00\x42>Z<github.com/metaprov/modelaapi/services/featurepipelinerun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=470,
)

_LISTFEATUREPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='ListFeaturePipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=470,
)


_LISTFEATUREPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='ListFeaturePipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=472,
  serialized_end=597,
)


_CREATEFEATUREPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='CreateFeaturePipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=720,
)


_CREATEFEATUREPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='CreateFeaturePipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=756,
)


_UPDATEFEATUREPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='UpdateFeaturePipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=758,
  serialized_end=879,
)


_UPDATEFEATUREPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='UpdateFeaturePipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=915,
)


_GETFEATUREPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='GetFeaturePipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=917,
  serialized_end=980,
)


_GETFEATUREPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='GetFeaturePipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=983,
  serialized_end=1116,
)


_DELETEFEATUREPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='DeleteFeaturePipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1118,
  serialized_end=1184,
)


_DELETEFEATUREPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='DeleteFeaturePipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1186,
  serialized_end=1220,
)

_LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY.containing_type = _LISTFEATUREPIPELINERUNREQUEST
_LISTFEATUREPIPELINERUNREQUEST.fields_by_name['labels'].message_type = _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY
_LISTFEATUREPIPELINERUNRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINERUNLIST
_CREATEFEATUREPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINERUN
_UPDATEFEATUREPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINERUN
_GETFEATUREPIPELINERUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINERUN
DESCRIPTOR.message_types_by_name['ListFeaturePipelineRunRequest'] = _LISTFEATUREPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturePipelineRunResponse'] = _LISTFEATUREPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRunRequest'] = _CREATEFEATUREPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRunResponse'] = _CREATEFEATUREPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRunRequest'] = _UPDATEFEATUREPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRunResponse'] = _UPDATEFEATUREPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['GetFeaturePipelineRunRequest'] = _GETFEATUREPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['GetFeaturePipelineRunResponse'] = _GETFEATUREPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRunRequest'] = _DELETEFEATUREPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRunResponse'] = _DELETEFEATUREPIPELINERUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRunRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRunRequest)
_sym_db.RegisterMessage(ListFeaturePipelineRunRequest.LabelsEntry)

ListFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRunResponse)

CreateFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRunRequest)

CreateFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRunResponse)

UpdateFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRunRequest)

UpdateFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRunResponse)

GetFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRunRequest)

GetFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRunResponse)

DeleteFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRunRequest)

DeleteFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRunResponse)


DESCRIPTOR._options = None
_LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY._options = None

_FEATUREPIPELINERUNSERVICE = _descriptor.ServiceDescriptor(
  name='FeaturePipelineRunService',
  full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1223,
  serialized_end=2504,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListFeaturePipelineRuns',
    full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService.ListFeaturePipelineRuns',
    index=0,
    containing_service=None,
    input_type=_LISTFEATUREPIPELINERUNREQUEST,
    output_type=_LISTFEATUREPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/v1/featurepipelineruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeaturePipelineRun',
    full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService.CreateFeaturePipelineRun',
    index=1,
    containing_service=None,
    input_type=_CREATEFEATUREPIPELINERUNREQUEST,
    output_type=_CREATEFEATUREPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\027/v1/featurepipelineruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeaturePipelineRun',
    full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService.GetFeaturePipelineRun',
    index=2,
    containing_service=None,
    input_type=_GETFEATUREPIPELINERUNREQUEST,
    output_type=_GETFEATUREPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/v1/featurepipelineruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeaturePipelineRun',
    full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService.UpdateFeaturePipelineRun',
    index=3,
    containing_service=None,
    input_type=_UPDATEFEATUREPIPELINERUNREQUEST,
    output_type=_UPDATEFEATUREPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\0021\032,/v1/featurepipelines/{feature.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeaturePipelineRun',
    full_name='github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService.DeleteFeaturePipelineRun',
    index=4,
    containing_service=None,
    input_type=_DELETEFEATUREPIPELINERUNREQUEST,
    output_type=_DELETEFEATUREPIPELINERUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEATUREPIPELINERUNSERVICE)

DESCRIPTOR.services_by_name['FeaturePipelineRunService'] = _FEATUREPIPELINERUNSERVICE

# @@protoc_insertion_point(module_scope)
